#!/usr/bin/env python
#
# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from google.appengine.ext import webapp
from google.appengine.ext.webapp import util
import os
from google.appengine.ext.webapp import template
from google.appengine.api import urlfetch

from BeautifulSoup import *

class MainHandler(webapp.RequestHandler):
  def get(self):
    template_values = {
            'url': None,
            }      
    path = os.path.join(os.path.dirname(__file__), 'index.html')
    self.response.out.write(template.render(path, template_values))

class StopInfoEntry(webapp.RequestHandler):
  def get(self):
    template_values = {
            'url': None,
            }      
    path = os.path.join(os.path.dirname(__file__), 'ajax.html')
    self.response.out.write(template.render(path, template_values))    

class StopEntry(webapp.RequestHandler):
  def get(self, number):
    n = number.replace('.','/')+'/'
    url = "http://campusbus.ntu.edu.sg/ntubus/index.php/m/main/geteta/" + n
    result = urlfetch.fetch(url)
    if result.status_code == 200:
      content = result.content
    else:
      content = 'None'

    soup = BeautifulSoup(content)
    body = soup.findAll('font')
    c = body[0].contents
    l = []
    for item in c:
      if type(item) == NavigableString:
        if item.startswith('Brought'):
          break
        l.append(item)
      elif type(item) == Tag and item.text:
        l.append(item.text)
    # extract information from l
    
    l1 = []
    title = 'Stop Information'
    for ind, item in enumerate(l):
      if item.find('Route')>=0:
        l1.append('<li class="sep">' + item+ '</li>')
      elif item.find('Next')>=0:
        l1.append('<li>' + item + '</li>')
      elif item.find('Bus Stop ID')>=0:
        title = l[ind+1]

    template_values = {
            'title': title,
            'content': l1,
            }    
    path = os.path.join(os.path.dirname(__file__), 'stopinfo.html')
    self.response.out.write(template.render(path, template_values))
    
def main():
  application = webapp.WSGIApplication([('/', MainHandler),
                                        ('/stop/(.*)', StopEntry),
					('/stopinfo', StopInfoEntry),
                                        ],
                                       debug=True)
  util.run_wsgi_app(application)


if __name__ == '__main__':
  main()
